@@ -25,14 +25,24 @@ https://github.com/mu-editor/mu/blob/master/win_installer.py
 import argparse
 import importlib.util as iutil
 import os
+import requests
 import shutil
 import subprocess
 import sys
 import tempfile
+import zipfile
 
 import yarg
 
 
+# URL to download assets that the installer needs and that will be put on
+# the assets directory when building the installer
+
+ASSETS_URL = os.environ.get(
+    'ASSETS_URL',
+    'https://github.com/spyder-ide/windows-installer-assets/'
+    'releases/download/0.0.1/assets.zip')
+
 # Packages to remove from the requirements for example pip or
 # external direct dependencies (python-language-server spyder-kernels)
 
@@ -43,8 +53,7 @@ UNWANTED_PACKAGES = os.environ.get('UNWANTED_PACKAGES', '').split()
 
 SKIP_PACKAGES = os.environ.get('SKIP_PACKAGES', '').split()
 
-
-# Packages to be added to the packages section regardles wheel checks or
+# Packages to be added to the packages section regardless wheel checks or
 # packages skipped, for example external direct dependencies
 # (spyder-kernels python-language-server)
 
@@ -89,8 +98,12 @@ packages=
     win32security
     ntsecuritycon
     {packages}
-files=black-20.8b1.dist-info > $INSTDIR/pkgs
+files={package_dist_info} > $INSTDIR/pkgs
+    black-20.8b1.dist-info > $INSTDIR/pkgs
     __main__.py > $INSTDIR/pkgs/jedi/inference/compiled/subprocess
+    lib
+    tcl86t.dll > $INSTDIR/pkgs
+    tk86t.dll > $INSTDIR/pkgs
 [Build]
 installer_name={installer_name}
 nsi_template={template}
@@ -196,7 +209,7 @@ def pypi_wheels_in(requirements, skip_packages):
 
 def package_name(requirement):
     """
-    Return the name component of a `name==version` formated requirement.
+    Return the name component of a `name==version` formatted requirement.
     """
     requirement_name = requirement.partition("==")[0].split("@")[0].strip()
     return requirement_name
@@ -230,6 +243,7 @@ def create_pynsist_cfg(
     repo_package_name = repo_about_file["__title__"]
     repo_version = repo_about_file["__installer_version__"]
     repo_author = repo_about_file["__author__"]
+    repo_dist_info = "{}-{}.dist-info".format(package, repo_version)
 
     requirements = [
         # Those from pip freeze except the package itself and packages local
@@ -270,6 +284,7 @@ def create_pynsist_cfg(
         packages="\n    ".join(packages),
         installer_name=installer_exe,
         template=template,
+        package_dist_info=repo_dist_info
     )
     with open(filename, "wt", encoding=encoding) as f:
         f.write(pynsist_cfg_payload)
@@ -281,6 +296,27 @@ def create_pynsist_cfg(
     return installer_exe
 
 
+def download_file(url, target_directory):
+    """
+    Download the URL to the target_directory and return the filename.
+    """
+    local_filename = os.path.join(target_directory, url.split("/")[-1])
+    r = requests.get(url, stream=True)
+    with open(local_filename, "wb") as f:
+        for chunk in r.iter_content(chunk_size=1024):
+            if chunk:  # filter out keep-alive new chunks
+                f.write(chunk)
+    return local_filename
+
+
+def unzip_file(filename, target_directory):
+    """
+    Given a filename, unzip it into the given target_directory.
+    """
+    with zipfile.ZipFile(filename) as z:
+        z.extractall(target_directory)
+
+
 def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
         license_path, extra_packages=None, conda_path=None, suffix=None,
         template=None):
@@ -292,6 +328,13 @@ def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
     (locking the dependencies set in setup.py) is generated and pynsist runned.
     """
     try:
+        print("Setting up assets from", ASSETS_URL)
+        print("Downloading assets from ", ASSETS_URL)
+        filename = download_file(ASSETS_URL, 'installers/Windows/assets')
+
+        print("Unzipping assets to", 'installers/Windows/assets')
+        unzip_file(filename, 'installers/Windows/assets')
+
         with tempfile.TemporaryDirectory(
                 prefix="installer-pynsist-") as work_dir:
             print("Temporary working directory at", work_dir)
@@ -310,6 +353,17 @@ def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
                 "installers/Windows/assets/jedi/__main__.py",
                 os.path.join(work_dir, "__main__.py"))
 
+            print("Copying required assets for Tkinter to work")
+            shutil.copytree(
+                "installers/Windows/assets/tcl/lib",
+                os.path.join(work_dir, "lib"))
+            shutil.copy(
+                "installers/Windows/assets/tcl/tcl86t.dll",
+                os.path.join(work_dir, "tcl86t.dll"))
+            shutil.copy(
+                "installers/Windows/assets/tcl/tk86t.dll",
+                os.path.join(work_dir, "tk86t.dll"))
+
             print("Copying NSIS plugins into discoverable path")
             shutil.copy(
                 "installers/Windows/assets/nsist/plugins/x86-unicode/"
@@ -358,6 +412,18 @@ def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
                             "pip", "install", repo_root,
                             "--no-warn-script-location"])
 
+            print("Copy package .dist-info into the pynsist future "
+                  "build directory")
+            package_info = about_dict(repo_root, package)
+            dist_info_dir = "{}-{}.dist-info".format(
+                package,
+                package_info["__installer_version__"])
+            shutil.copytree(
+                os.path.join(
+                    work_dir, "packaging-env/Lib/site-packages",
+                    dist_info_dir),
+                os.path.join(work_dir, dist_info_dir))
+
             if extra_packages:
                 print("Installing extra packages.")
                 subprocess_run([env_python, "-m", "pip", "install", "-r",
