@@ -19,10 +19,7 @@ import shutil
 import sys
 import tempfile
 from textwrap import dedent
-try:
-    from unittest.mock import Mock
-except ImportError:
-    from mock import Mock  # Python 2
+from unittest.mock import Mock
 
 # Third party imports
 import IPython
@@ -1339,6 +1336,7 @@ def test_remove_old_stderr_files(ipyconsole, qtbot):
     assert not osp.isfile(osp.join(tmpdir, 'foo.stderr'))
 
 
+@flaky(max_runs=10)
 @pytest.mark.use_startup_wdir
 def test_console_working_directory(ipyconsole, qtbot):
     """Test for checking the working directory."""
